CHANGELOG
-----------

v3.4.1 2023-10-05
~~~~~~~~~~~~~~~~~

- Remove setuptools_scm


v3.4.0 2023-10-05
~~~~~~~~~~~~~~~~~

- Build wheels for Python 3.12

v3.3.0 2023-07-29
~~~~~~~~~~~~~~~~~

- Upgrade xxHash to v0.8.2
- Drop support for Python 3.6

v3.2.0 2022-12-28
~~~~~~~~~~~~~~~~~

This is the last version to support Python 3.6

- Build Python 3.11 wheels.
- Remove setup.py test_suites, call unittest directly

v3.1.0 2022-10-19
~~~~~~~~~~~~~~~~~

- Type annotations.
- Enabled muslinux wheels building.

v3.0.0 2022-02-25
~~~~~~~~~~~~~~~~~

- New set `algorithms_available` lists all implemented algorithms in `xxhash`
  package.
- Upgrade xxHash to v0.8.1.
- Drop support for EOL Python versions, require python >= 3.6 from now on.
- Migrate to github actions and build arm64 wheels for macOS.
- Always release GIL.


v2.0.2 2021-04-15
~~~~~~~~~~~~~~~~~

- Fix Travis CI OSX dpl python2.7 get-pip.py error

v2.0.1 2021-04-15
~~~~~~~~~~~~~~~~~

- Only to trigger Python 3.9 wheels building.

v2.0.0 2020-08-03
~~~~~~~~~~~~~~~~~

- **Require xxHash version >= v0.8.0**
- Upgrade xxHash to v0.8.0
- XXH3 hashes: `xxh3_64`, `xxh3_128`, and their oneshot functions

v1.4.4 2020-06-20
~~~~~~~~~~~~~~~~~

- Upgrade xxHash to v0.7.3
- Stop using PEP393 deprecated APIs
- Use XXH(32|64)_canonicalFromHash to replace u2bytes and ull2bytes

v1.4.3 2019-11-12
~~~~~~~~~~~~~~~~~

- Upgrade xxHash to v0.7.2
- Python 3.8 wheels

v1.4.2 2019-10-13
~~~~~~~~~~~~~~~~~

- Fixed: setup.py fails when reading README.rst and the default encoding is not UTF-8

v1.4.1 2019-08-27
~~~~~~~~~~~~~~~~~

- Fixed: xxh3.h in missing from source tarball

v1.4.0 2019-08-25
~~~~~~~~~~~~~~~~~

- Upgrade xxHash to v0.7.1

v1.3.0 2018-10-21
~~~~~~~~~~~~~~~~~

- Wheels are now built automatically
- Split CFFI variant into a separate package `ifduyue/python-xxhash-cffi <https://github.com/ifduyue/python-xxhash-cffi>`_

v1.2.0 2018-07-13
~~~~~~~~~~~~~~~~~

- Add oneshot functions xxh{32,64}_{,int,hex}digest

v1.1.0 2018-07-05
~~~~~~~~~~~~~~~~~

- Allow input larger than 2GB
- Release the GIL on sufficiently large input
- Drop support for Python 3.2

v1.0.1 2017-03-02
~~~~~~~~~~~~~~~~~~

- Free state actively, instead of delegating it to ffi.gc

v1.0.0 2017-02-10
~~~~~~~~~~~~~~~~~~

- Fixed copy() segfault
- Added CFFI variant

v0.6.3 2017-02-10
~~~~~~~~~~~~~~~~~~

- Fixed copy() segfault

v0.6.2 2017-02-10
~~~~~~~~~~~~~~~~~~

- Upgrade xxHash to v0.6.2

v0.6.1 2016-06-26
~~~~~~~~~~~~~~~~~~

- Upgrade xxHash to v0.6.1

v0.5.0 2016-03-02
~~~~~~~~~~~~~~~~~~

- Upgrade xxHash to v0.5.0

v0.4.3 2015-08-21
~~~~~~~~~~~~~~~~~~

- Upgrade xxHash to r42

v0.4.1 2015-08-16
~~~~~~~~~~~~~~~~~~

- Upgrade xxHash to r41

v0.4.0 2015-08-05
~~~~~~~~~~~~~~~~~~

- Added method reset
- Upgrade xxHash to r40

v0.3.2 2015-01-27
~~~~~~~~~~~~~~~~~~

- Fixed some typos in docstrings

v0.3.1 2015-01-24
~~~~~~~~~~~~~~~~~~

- Upgrade xxHash to r39

v0.3.0 2014-11-11
~~~~~~~~~~~~~~~~~~

- Change digest() from little-endian representation to big-endian representation of the integer digest.
  This change breaks compatibility (digest() results are different).

v0.2.0 2014-10-25
~~~~~~~~~~~~~~~~~~

- Make this package hashlib-compliant

v0.1.3 2014-10-23
~~~~~~~~~~~~~~~~~~

- Update xxHash to r37

v0.1.2 2014-10-19
~~~~~~~~~~~~~~~~~~

- Improve: Check XXHnn_init() return value.
- Update xxHash to r36

v0.1.1 2014-08-07
~~~~~~~~~~~~~~~~~~

- Improve: Can now be built with Visual C++ Compiler.

v0.1.0 2014-08-05
~~~~~~~~~~~~~~~~~~

- New: XXH32 and XXH64 type, which support partially update.
- Fix: build under Python 3.4

v0.0.2 2014-08-03
~~~~~~~~~~~~~~~~~~

- NEW: Support Python 3

v0.0.1 2014-07-30
~~~~~~~~~~~~~~~~~~

- NEW: xxh32 and xxh64
